@@ -1,10 +1,10 @@
 /* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-#ifndef H_PROCMAN_E_DATE_1135695432
-#define H_PROCMAN_E_DATE_1135695432
+#ifndef _GSM_E_DATE_H_
+#define _GSM_E_DATE_H_
 
 #include <time.h>
 
 char *
 procman_format_date_for_display(time_t d);
 
-#endif /* H_PROCMAN_E_DATE_1135695432 */
+#endif /* _GSM_E_DATE_H_ */
